pub struct BlockDescription {
pub id: BlockId,
pub type_name: String,
pub instance_name: String,
pub stream_inputs: Vec<String>,
pub stream_outputs: Vec<String>,
pub message_inputs: Vec<String>,
pub message_outputs: Vec<String>,
pub blocking: bool,
}Expand description
Serializable description of one block instance.
This is the block-level metadata returned by the control port and runtime flowgraph handles.
Fields
id: BlockIdBlock id inside the flowgraph.
type_name: StringRust type name of the block kernel.
instance_name: StringRuntime instance name assigned to the block.
stream_inputs: Vec<String>Stream input port names.
stream_outputs: Vec<String>Stream output port names.
message_inputs: Vec<String>Message input port names.
message_outputs: Vec<String>Message output port names.
blocking: boolWhether the block runs on a blocking/local execution path.
Blocking blocks have an async API but are spawned in a separate thread, i.e., it is ok to block inside the async function.