pub struct BlockId(pub usize);Expand description
Identifier of a block inside one flowgraph.
Block ids are assigned when blocks are added to a flowgraph. They are useful for type-erased connections, runtime descriptions, and message calls to a running flowgraph. The numeric value is only meaningful together with the flowgraph that assigned it.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl<'de> Deserialize<'de> for BlockId
impl<'de> Deserialize<'de> for BlockId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Copy for BlockId
impl Eq for BlockId
impl StructuralPartialEq for BlockId