pub struct FlowgraphId(pub usize);Expand description
Identifier of a flowgraph known to a runtime control handle.
Runtime handles assign these ids as flowgraphs are registered with the control plane. They are used by the native REST API and by remote clients.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for FlowgraphId
impl Clone for FlowgraphId
Sourcefn clone(&self) -> FlowgraphId
fn clone(&self) -> FlowgraphId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowgraphId
impl Debug for FlowgraphId
Sourceimpl<'de> Deserialize<'de> for FlowgraphId
impl<'de> Deserialize<'de> for FlowgraphId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FlowgraphId
impl Display for FlowgraphId
Sourceimpl From<usize> for FlowgraphId
impl From<usize> for FlowgraphId
Sourceimpl PartialEq for FlowgraphId
impl PartialEq for FlowgraphId
Sourcefn eq(&self, other: &FlowgraphId) -> bool
fn eq(&self, other: &FlowgraphId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FlowgraphId
impl Serialize for FlowgraphId
impl Copy for FlowgraphId
impl Eq for FlowgraphId
impl StructuralPartialEq for FlowgraphId